@@ -1,6 +1,7 @@
 package Module::Build::Database::Helpers;
 use strict;
 use warnings;
+use File::Which qw( which );
 
 use Sub::Exporter -setup => {
     exports => [
@@ -35,7 +36,7 @@ sub verify_bin {
         my @look_for = (ref $bin->{$label} eq 'ARRAY' ? @{ $bin->{$label} } : $bin->{$label});
         my $found;
         for my $potential_cmd (@look_for) {
-            last if $found = qx[which $potential_cmd];
+            last if $found = which $potential_cmd;
             if(defined $try && -x "$try/$potential_cmd") {
                 $found = "$try/$potential_cmd";
                 last;
